@@ -8,14 +8,15 @@ package Aniki::Plugin::Count {
 
     sub count {
         my ($self, $table, $column, $where, $opt) = @_;
-        $column ||= '*';
+        $column //= '*';
 
         if (ref $column) {
             Carp::croak('Do not pass HashRef/ArrayRef to second argument. Usage: $db->count($table[, $column[, $where[, $opt]]])');
         }
 
         my ($sql, @binds) = $self->query_builder->select($table, [\"COUNT($column)"], $where, $opt);
-        return $self->dbh->select_one($sql, @binds);
+        my ($count) = $self->dbh->selectrow_array($sql, undef, @binds);
+        return $count;
     }
 }
 
@@ -42,10 +43,6 @@ Aniki::Plugin::Count - Count rows in database.
     $db->count('user'); # => The number of rows in 'user' table.
     $db->count('user', '*', {type => 2}); # => SELECT COUNT(*) FROM user WHERE type=2
 
-=head1 DESCRIPTION
-
-TODO
-
 =head1 SEE ALSO
 
 L<perl>
