@@ -4,9 +4,9 @@ package Aniki::Plugin::Pager {
     use namespace::sweep;
     use Mouse::Role;
     use Data::Page::NoTotalEntries;
-    use Aniki::Collection::Role::Pager;
+    use Aniki::Result::Role::Pager;
 
-    requires qw/select result_class/;
+    requires qw/select guess_result_class/;
 
     sub select_with_pager {
         my ($self, $table_name, $where, $opt) = @_;
@@ -22,7 +22,7 @@ package Aniki::Plugin::Pager {
 
         my $has_next = $rows < $result->count ? 1 : 0;
         if ($has_next) {
-            $result = $self->result_class->new(
+            $result = $self->guess_result_class($table_name)->new(
                 table_name           => $table_name,
                 handler              => $self,
                 row_datas            => [@{$result->row_datas}[0..$result->count-2]],
@@ -40,8 +40,8 @@ package Aniki::Plugin::Pager {
             has_next             => $has_next,
             entries_on_this_page => $result->count,
         );
-        $result->meta->does_role('Aniki::Collection::Role::Pager')
-            or Mouse::Util::apply_all_roles($result, 'Aniki::Collection::Role::Pager');
+        $result->meta->does_role('Aniki::Result::Role::Pager')
+            or Mouse::Util::apply_all_roles($result, 'Aniki::Result::Role::Pager');
         $result->pager($pager);
 
         return $result;
@@ -68,11 +68,8 @@ Aniki::Plugin::Pager - SELECT with pager
 
     package main;
     my $db = MyDB->new(...);
-    $db->select_with_pager('user', '*', {type => 2}); # => SELECT COUNT(*) FROM user WHERE type=2
-
-=head1 DESCRIPTION
-
-TODO
+    my $result = $db->select_with_pager('user', { type => 2 }, { page => 1, rows => 10 }); # => Aniki::Result::Collection(+Aniki::Result::Role::Pager)
+    $result->pager; # => Data::Page::NoTotalEntries
 
 =head1 SEE ALSO
 
